SystemOrganization addCategory: #'FileSystem-Tests-AnsiStreams'!

TestCase subclass: #FileSystemReadStreamTest
	instanceVariableNames: 'filesystem stream'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FileSystem-Tests-AnsiStreams'!

!FileSystemReadStreamTest methodsFor: 'support' stamp: 'cwp 7/29/2009 22:43'!
contents: aByteArray
	stream := filesystem writeStreamOn: 'griffle'.
	stream nextPutAll: aByteArray.
	stream close.
	stream := filesystem readStreamOn: 'griffle'! !

!FileSystemReadStreamTest methodsFor: 'running' stamp: 'EstebanLorenzano 4/2/2012 11:43'!
setUp
	filesystem := FileSystem memory.
	! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/29/2009 22:38'!
testAtEnd
	self contents: #().
	self assert: stream atEnd! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/29/2009 22:57'!
testDo
	| contents |
	self contents: #(1 2 3).
	contents := Array streamContents:
		[:out |
		stream do: [:ea | out nextPut: ea]].
	self assert: contents = #(1 2 3)! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/29/2009 23:00'!
testNext
	self contents: #(1 2 3).
	self assert: stream next = 1! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/29/2009 23:07'!
testNextColon
	| result |
	self contents: #(1 2 3 4 5).
	result := stream next: 3.
	self assert: result = #(1 2 3) asByteArray.! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/30/2009 23:54'!
testNextInto
	| result buffer |
	self contents: #(1 2 3 4 5).
	buffer := ByteArray new: 3.
	result := stream nextInto: buffer.
	self assert: result == buffer.
	self assert: result = #(1 2 3) asByteArray! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/29/2009 23:30'!
testNextLineCR
	| result tail |
	self contents: #(97 97 97 13 98 98 98).
	result := stream nextLine.
	self assert: result = #(97 97 97) asByteArray.
	tail := stream next: 3.
	self assert: tail = #(98 98 98) asByteArray! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/29/2009 23:31'!
testNextLineCRLF
	| line tail |
	self contents: #(97 97 97 13 10 98 98 98).
	line := stream nextLine.
	self assert: line = #(97 97 97) asByteArray.
	tail := stream next: 3.
	self assert: tail = #(98 98 98) asByteArray! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/29/2009 23:31'!
testNextLineLF
	| result tail |
	self contents: #(97 97 97 10 98 98 98).
	result := stream nextLine.
	self assert: result = #(97 97 97) asByteArray.
	tail := stream next: 3.
	self assert: tail = #(98 98 98) asByteArray! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/30/2009 23:04'!
testNextMatchFalse
	self contents: #(1 2 3).
	self deny: (stream nextMatchFor: 5)! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/30/2009 23:01'!
testNextMatchTrue
	self contents: #(1 2 3).
	self assert: (stream nextMatchFor: 1)! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 1/9/2012 18:07'!
testNextPutAllThenNextPut

	| sourceArray loadedArray serializer materializer |

	stream := filesystem writeStreamOn: 'griffle'.
	stream nextPutAll: 'xxx' asByteArray.
	stream nextPut: 42.
	stream close. 

	stream := filesystem readStreamOn: 'griffle'.
	self assert: (stream next: 3) asString = 'xxx'.
	self assert: stream next  = 42.! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/29/2009 22:46'!
testNotAtEnd
	self contents: #(1 2 3).
	self deny: stream atEnd! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/30/2009 23:05'!
testPeek
	self contents: #(1 2 3).
	self assert: stream peek = 1.
	self assert: stream next = 1.! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/30/2009 23:06'!
testPeekForFalse
	self contents: #(1 2 3).
	self deny: (stream peekFor: 5)
	! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/30/2009 23:06'!
testPeekForTrue
	self contents: #(1 2 3).
	self assert: (stream peekFor: 1)
	! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/30/2009 23:17'!
testSkip
	self contents: #(1 2 3 4 5).
	stream skip: 3.
	self assert: stream position = 4! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/30/2009 23:18'!
testSkipPastEnd
	self contents: #(1 2 3 4 5).
	stream skip: 10.
	self assert: stream atEnd! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/30/2009 23:20'!
testSkipTo
	self contents: #(1 2 3 4 5).
	stream skipTo: 3.
	self assert: stream position = 4! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/30/2009 23:24'!
testSkipToEnd
	self contents: #(1 2 3 4 5).
	stream skipTo: 10.
	self assert: stream atEnd! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/30/2009 23:27'!
testSkipToFalse
	self contents: #(1 2 3 4 5).
	self deny: (stream skipTo: 10).
	! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/30/2009 23:25'!
testSkipToTrue
	self contents: #(1 2 3 4 5).
	self assert: (stream skipTo: 4).
	! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/30/2009 23:38'!
testUpTo
	| result |
	self contents: #(1 2 3 4 5).
	result := stream upTo: 4.
	self assert: result = #(1 2 3) asByteArray! !

!FileSystemReadStreamTest methodsFor: 'tests' stamp: 'cwp 7/30/2009 23:38'!
testUpToEnd
	| result |
	self contents: #(1 2 3 4 5).
	result := stream upTo: 7.
	self assert: result = #(1 2 3 4 5) asByteArray! !

TestCase subclass: #FileSystemWriteStreamTest
	instanceVariableNames: 'filesystem stream'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FileSystem-Tests-AnsiStreams'!

!FileSystemWriteStreamTest methodsFor: 'accessing' stamp: 'EstebanLorenzano 4/2/2012 11:42'!
contents
	^ (filesystem instVarNamed: 'store')
		nodeAt: Path / 'giffle'
		ifPresent: [:bytes | bytes]
		ifAbsent: [self signalFailure: 'No file!!']! !

!FileSystemWriteStreamTest methodsFor: 'running' stamp: 'EstebanLorenzano 4/2/2012 11:43'!
setUp
	filesystem := FileSystem memory.
	stream := filesystem writeStreamOn: 'giffle'! !

!FileSystemWriteStreamTest methodsFor: 'tests' stamp: 'cwp 7/28/2009 22:48'!
testClose
	self
		shouldnt: [stream close]
		raise: Error! !

!FileSystemWriteStreamTest methodsFor: 'tests' stamp: 'cwp 7/29/2009 21:55'!
testContents
	stream nextPutAll: #(42 43 44).
	self assert: stream contents = #(42 43 44) asByteArray! !

!FileSystemWriteStreamTest methodsFor: 'tests' stamp: 'CamilloBruni 8/12/2011 14:34'!
testCr
	stream cr.
	self assert: self contents first = Character cr asInteger! !

!FileSystemWriteStreamTest methodsFor: 'tests' stamp: 'CamilloBruni 8/12/2011 14:42'!
testCrLf
	stream crlf.
	self assert: self contents first = Character cr asInteger.
	self assert: self contents second = Character lf asInteger.! !

!FileSystemWriteStreamTest methodsFor: 'tests' stamp: 'CamilloBruni 8/12/2011 14:41'!
testCrTab
	stream crtab.
	self assert: self contents first = Character cr asInteger.
	self assert: self contents second = Character tab asInteger.! !

!FileSystemWriteStreamTest methodsFor: 'tests' stamp: 'cwp 7/28/2009 22:21'!
testFlush
	
	self
		shouldnt: [stream flush]
		raise: Error! !

!FileSystemWriteStreamTest methodsFor: 'tests' stamp: 'CamilloBruni 8/12/2011 14:34'!
testLf
	stream lf.
	self assert: self contents first = Character lf asInteger! !

!FileSystemWriteStreamTest methodsFor: 'tests' stamp: 'cwp 7/29/2009 21:55'!
testNextPut
	stream nextPut: 42.
	self assert: self contents first = 42! !

!FileSystemWriteStreamTest methodsFor: 'tests' stamp: 'cwp 7/29/2009 22:23'!
testNextPutAll
	stream nextPutAll: #(42 43 44).
	stream flush.
	self assert: self contents = #(42 43 44) asByteArray! !

!FileSystemWriteStreamTest methodsFor: 'tests' stamp: 'CamilloBruni 8/12/2011 15:22'!
testOverriding
	stream 
		nextPutAll: 'foo bar';
		close.
	self assert: (filesystem root resolve: 'giffle') 
		readStream contents asString = 'foo bar'.
	
	(filesystem root resolve: 'giffle') writeStreamDo: [ :s | s nextPutAll: 'x' ].
	self assert: (filesystem / 'giffle') 
		readStream contents asString = 'x'! !

!FileSystemWriteStreamTest methodsFor: 'tests' stamp: 'CamilloBruni 8/12/2011 14:38'!
testPipeIn
	stream << #(42 43 44).
	stream flush.
	self assert: self contents = #(42 43 44) asByteArray! !

!FileSystemWriteStreamTest methodsFor: 'tests' stamp: 'CamilloBruni 8/12/2011 14:34'!
testSpace
	stream space.
	self assert: self contents first = Character space asInteger! !

!FileSystemWriteStreamTest methodsFor: 'tests' stamp: 'CamilloBruni 8/12/2011 14:40'!
testSpaceRepeat
	stream space: 3.
	self assert: self contents first = Character space asInteger.
	self assert: self contents second = Character space asInteger.
	self assert: self contents third = Character space asInteger.! !

!FileSystemWriteStreamTest methodsFor: 'tests' stamp: 'cwp 7/29/2009 21:56'!
testTab
	stream tab.
	self assert: self contents first = 9! !

!FileSystemWriteStreamTest methodsFor: 'tests' stamp: 'CamilloBruni 8/12/2011 14:40'!
testTabRepeat
	stream tab: 3.
	self assert: self contents first = Character tab asInteger.
	self assert: self contents second = Character tab asInteger.
	self assert: self contents third = Character tab asInteger.! !

!FileSystemWriteStreamTest methodsFor: 'tests' stamp: 'cwp 10/15/2009 22:04'!
testTruncate
	stream 
		nextPutAll: #(42 43 44 45 46);
		flush;
		position: 4;
		truncate.
	self assert: self contents = #(42 43 44) asByteArray! !

!FileSystemWriteStreamTest methodsFor: 'tests' stamp: 'cwp 10/15/2009 21:50'!
testTruncateTo
	stream nextPutAll: #(42 43 44 45 46).
	stream flush.
	stream truncateTo: 3.
	self assert: self contents = #(42 43 44) asByteArray! !
